@@ -178,12 +178,13 @@ class PaddedBatch:
         return self
 
     def at_position(self, pos):
-        """Fetch an item by its position in the batch."""
+        """Gets the position."""
         key = self.__keys[pos]
         return getattr(self, key)
 
     @property
     def batchsize(self):
+        """Returns the bach size"""
         return self.__length
 
 
@@ -250,16 +251,21 @@ class BatchsizeGuesser:
         return bs
 
     def attr_based(self, batch):
+        """Implementation of attr_based."""
         return batch.batchsize
 
     def torch_tensor_bs(self, batch):
+        """Implementation of torch_tensor_bs."""
         return batch.shape[0]
 
     def len_of_first(self, batch):
+        """Implementation of len_of_first."""
         return len(batch[0])
 
     def len_of_iter_first(self, batch):
+        """Implementation of len_of_iter_first."""
         return len(next(iter(batch)))
 
     def fallback(self, batch):
+        """Implementation of fallback."""
         return 1
