@@ -52,8 +52,15 @@ from speechbrain.utils.checkpoints import (
 # Optional support for webdataset
 try:
     import webdataset as wds
+    from importlib_metadata import version
 
     WDS_AVAILABLE = True
+
+    # Use appropriate class based on webdataset version
+    if version("webdataset")[0:4] == "0.1.":
+        WDS_CLASS = wds.dataset.Composable
+    else:
+        WDS_CLASS = wds.DataPipeline
 except ImportError:
     WDS_AVAILABLE = False
 
@@ -120,7 +127,7 @@ def make_dataloader(dataset, looped_nominal_epoch=None, **loader_kwargs):
     # which requires batch_size = None in the DataLoader
     if (
         WDS_AVAILABLE
-        and isinstance(dataset, wds.dataset.Composable)
+        and isinstance(dataset, WDS_CLASS)
         and "batch_size" not in loader_kwargs
     ):
         loader_kwargs["batch_size"] = None
@@ -316,6 +323,7 @@ class LoopedLoader:
 
     @mark_as_saver
     def save(self, path):
+        """Saves the needed information."""
         with open(path, "w") as fo:
             print(self.step, file=fo)
             print(self.total_steps, file=fo)
@@ -323,6 +331,7 @@ class LoopedLoader:
 
     @mark_as_loader
     def load(self, path, end_of_epoch=True, device=None):
+        """Loads the needed information."""
         del device  # Unused here
         with open(path) as fi:
             self.step = int(fi.readline().strip())
